#!/bin/sh

ACTION=${1}
shift 1

get_image() {
  IMAGE_NAME="stable-8922"
}

do_install_detail() {
  local config=`uci get jitsi.@jitsi[0].config_path 2>/dev/null`
  local port=`uci get jitsi.@jitsi[0].port 2>/dev/null`
  local IMAGE_NAME=`uci get jitsi.@jitsi[0].image_name 2>/dev/null`
  local username=`uci get jitsi.@jitsi[0].username 2>/dev/null`
  local password=`uci get jitsi.@jitsi[0].password 2>/dev/null`
  local wireguard=`uci get jitsi.@jitsi[0].wireguard 2>/dev/null`
  local domain=`uci get jitsi.@jitsi[0].domain 2>/dev/null`

  #Generate the generic environment variables for the docker-compose

  GEN_PASS=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  GEN_PASS2=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  
  # Get our local LAN IP Address
  LAN_IP=$(uci get network.lan.ipaddr)
  # Strip trailing network mask
  LAN_IP="${LAN_IP%/*}"
   
  if [ -z "$config" ]; then
      echo "config path is empty!"
      exit 1
  fi

  [ -z "$port" ] && port=8443
  [ -z "$IMAGE_NAME" ] && IMAGE_NAME=stable-8922
  [ -z "$username" ] && username=admin
  [ -z "$password" ] && password=password
  [ -z "$wireguard" ] && wireguard=$LAN_IP
  [ -z "$domain" ] && domain=privatecloud.lan


echo "downloading Jitsi..."
wget https://github.com/jitsi/docker-jitsi-meet/archive/refs/tags/$IMAGE_NAME.tar.gz

chmod 777 $IMAGE_NAME.tar.gz

echo "extracting Jitsi..."
tar xzvf $config/jitsi/$IMAGE_NAME.tar.gz -C $config/jitsi/

cd $config/jitsi/docker-jitsi-meet-$IMAGE_NAME/

cp $config/jitsi/docker-jitsi-meet-$IMAGE_NAME/env.example $config/jitsi/docker-jitsi-meet-$IMAGE_NAME/.env

echo "changing env variables..."
# Edit our .env to enable public URL (required)
sed -i -e "s/#PUBLIC_URL=/PUBLIC_URL=/g" "$config/jitsi/docker-jitsi-meet-$IMAGE_NAME/.env"

# Edit our .env to set public URL (required)
sed -i -e "s/meet.example.com/$domain/g" "$config/jitsi/docker-jitsi-meet-$IMAGE_NAME/.env"

# Change JVB http port
#sed -i -e "s/# JaaS Components (beta)/JVB_COLIBRI_PORT=8088/g" "$config/jitsi/docker-jitsi-meet-$IMAGE_NAME/.env"

# Set local IP and Wireguard for WebRTC
sed -i -e "s/#JVB_ADVERTISE_IPS=192.168.1.1,1.2.3.4/JVB_ADVERTISE_IPS=LAN_IP,$LAN_IP,$wireguard/g" "$config/jitsi/docker-jitsi-meet-$IMAGE_NAME/.env"

# Set container restart policy
sed -i -e "s/#RESTART_POLICY=unless-stopped/RESTART_POLICY=unless-stopped/g" "$config/jitsi/docker-jitsi-meet-$IMAGE_NAME/.env"

# Enable Auth
sed -i -e "s/#ENABLE_AUTH=1/ENABLE_AUTH=1/g" "$config/jitsi/docker-jitsi-meet-$IMAGE_NAME/.env"

# Enable guest access
sed -i -e "s/#ENABLE_GUESTS=1/ENABLE_GUESTS=1/g" "$config/jitsi/docker-jitsi-meet-$IMAGE_NAME/.env"

# Set Auth type to internal
sed -i -e "s/#AUTH_TYPE=internal/AUTH_TYPE=internal/g" "$config/jitsi/docker-jitsi-meet-$IMAGE_NAME/.env"

echo "Setting strong passwords..."
#Set strong passwordss
./gen-passwords.sh

#make config directory
mkdir -p ~/.jitsi-meet-cfg/{web,transcripts,prosody/config,prosody/prosody-plugins-custom,jicofo,jvb,jigasi,jibri}

echo "Installing..."
docker-compose up -d

echo "Setting Host Password..."
docker-compose exec prosody /bin/bash -c "prosodyctl --config /config/prosody.cfg.lua register $username meet.jitsi $password"


 
  # Add a new list option to the "shortcutmenu" configuration file
  uci add shortcutmenu lists
  uci set shortcutmenu.@lists[-1].webname="$IMAGE_NAME"
  uci set shortcutmenu.@lists[-1].weburl="$LAN_IP:$port"
  uci set shortcutmenu.@lists[-1].webpath="/"
  uci commit shortcutmenu

}

usage() {
  echo "usage: $0 sub-command"
  echo "where sub-command is one of:"
  echo "      install                Install jitsi"
  echo "      upgrade                Upgrade jitsi"
  echo "      rm/start/stop/restart  Remove/Start/Stop/Restart jitsi"
  echo "      status                 jitsi status"
  echo "      port                   jitsi port"
}

case ${ACTION} in
  "install")
    get_image
    do_install_detail
  ;;
  "upgrade")
    get_image
    do_install_detail
  ;;
  "rm")
    docker rm -f jitsi
  ;;
  "start" | "stop" | "restart")
    docker ${ACTION} jitsi
  ;;
  "status")
    docker ps --all -f 'name=jitsi' --format '{{.State}}'
  ;;
  "port")
    docker ps --all -f 'name=jitsi' --format '{{.Ports}}' | grep -om1 '0.0.0.0:[0-9]*' | sed 's/0.0.0.0://'
  ;;
  *)
    usage
    exit 1
  ;;
esac
